import { defineComponent } from 'vue';
import * as common from 'schema-based-json-editor';
import { Select2 } from "select2-vue-component";
import { Icon } from './icon';
import { Optional } from './optional';
import { Description } from './description';
import { booleanEditorTemplateHtml } from './variables';
export var BooleanEditor = defineComponent({
    render: booleanEditorTemplateHtml,
    components: {
        icon: Icon,
        optional: Optional,
        description: Description,
        select2: Select2,
    },
    props: {
        schema: {
            type: Object,
            required: true,
        },
        initialValue: Boolean,
        title: [String, Number],
        theme: {
            type: Object,
            required: true,
        },
        icon: {
            type: Object,
            required: true,
        },
        locale: {
            type: Object,
            required: true,
        },
        readonly: Boolean,
        required: Boolean,
        hasDeleteButton: {
            type: Boolean,
            required: true,
        },
    },
    data: function () {
        return {
            value: false,
            buttonGroupStyle: common.buttonGroupStyleString,
        };
    },
    beforeMount: function () {
        this.value = common.getDefaultValue(this.required, this.schema, this.initialValue);
        this.$emit('update-value', { value: this.value, isValid: true });
    },
    computed: {
        isReadOnly: function () {
            return this.readonly || this.schema.readonly;
        },
        hasDeleteButtonFunction: function () {
            return this.hasDeleteButton && !this.isReadOnly;
        },
        titleToShow: function () {
            return common.getTitle(this.title, this.schema.title);
        },
        booleanOptions: function () {
            return [
                {
                    value: true,
                    label: this.locale.info.true
                },
                {
                    value: false,
                    label: this.locale.info.false
                }
            ];
        },
        className: function () {
            var rowClass = this.theme.row;
            return this.schema.className ? rowClass + ' ' + this.schema.className : rowClass;
        },
    },
    methods: {
        onChange: function () {
            this.value = !this.value;
            this.$emit('update-value', { value: this.value, isValid: true });
        },
        toggleOptional: function () {
            this.value = common.toggleOptional(this.value, this.schema, this.initialValue);
            this.$emit('update-value', { value: this.value, isValid: true });
        },
    }
});
