import { defineComponent } from 'vue';
import * as common from 'schema-based-json-editor';
import { Icon } from './icon';
import { Optional } from './optional';
import { Description } from './description';
import { nullEditorTemplateHtml } from './variables';
export var NullEditor = defineComponent({
    render: nullEditorTemplateHtml,
    components: {
        icon: Icon,
        optional: Optional,
        description: Description
    },
    props: {
        schema: {
            type: Object,
            required: true,
        },
        initialValue: null,
        title: [String, Number],
        theme: {
            type: Object,
            required: true,
        },
        icon: {
            type: Object,
            requried: true,
        },
        locale: {
            type: Object,
            required: true,
        },
        readonly: Boolean,
        required: Boolean,
        hasDeleteButton: {
            type: Boolean,
            required: true,
        },
    },
    data: function () {
        return {
            value: null,
            buttonGroupStyle: common.buttonGroupStyleString,
        };
    },
    beforeMount: function () {
        this.value = common.getDefaultValue(this.required, this.schema, this.initialValue);
        this.$emit('update-value', { value: this.value, isValid: true });
    },
    computed: {
        isReadOnly: function () {
            return this.readonly || this.schema.readonly;
        },
        hasDeleteButtonFunction: function () {
            return this.hasDeleteButton && !this.isReadOnly;
        },
        titleToShow: function () {
            return common.getTitle(this.title, this.schema.title);
        },
    },
    methods: {
        toggleOptional: function () {
            this.value = common.toggleOptional(this.value, this.schema, this.initialValue);
            this.$emit('update-value', { value: this.value, isValid: true });
        }
    }
});
